from nib import jinja

@jinja('filter')
def itemfilter(items, attrs=None):
    if hasattr:
        if type(attrs) != list:
            attrs = list(attrs)
        for attr in attrs:
            items = filter(lambda i: hasattr(i, attr), items)
    return items



import markdown
from nib import Processor, markup

@markup(['.md', '.mkdn'])
class MarkdownProcessor(Processor):
    def __init__(self, options):
        self.options = options
        self.markdown = markdown.Markdown(output_format='html5')

    def document(self, document):
        document.short = self.markdown.convert(document.short)
        document.content = self.markdown.convert(document.content)
        document.extension = '.html'
        return document



version = '0.4.5'

from os import path
cwd = path.abspath(path.dirname(__file__))

try:
    import nib.yaml as yaml
    from nib.config import Config
    from nib.document import Document
    from nib.resource import Resource
    from nib.render import Render, jinja
    from nib.processor import Processor
    from nib.processor import before, after, document, resource, markup
    from nib.build import Build

    import nib.plugins

except ImportError:
    # let's hope this only happens in setup.py until I find a better way
    pass
